@@ -68,7 +68,7 @@ def main():
     if addcsvtstamp:
         csvfname  = csvfname+"-"+tstamp+".csv"
     if not regen:    
-        runconfig.dhostname = input("Enter the Destination Host To Test : ")    
+        runconfig.dhostname = input("Enter the Destination Host To Test : ")         
 
     reportutil.init()
 
@@ -76,7 +76,7 @@ def main():
     ra = ""
     hs = "<html>\n<head>\n<style>\ntable, th, td {\n  border: 1px dotted black;\n border-collapse: collapse}</style>\n<title>API Test Report Summary</title></head><body><br>\n"
     print ("\n------- Starting API Tests: Testing all APIs in a spec one fuzz attack type at a time. \n")
-    #print(regen, runconfig.apispeclist, fuzzattacklist, dir(runconfig))
+    print(regen, runconfig.apispeclist, fuzzattacklist, dir(runconfig))
     ra = perattackcall(regen, runconfig.apispeclist, fuzzattacklist)
     
     (rsum, detail, rfailed, rskipped) = sumreport.sumperattack(csvfname, runconfig.apispeclist, fuzzattacklist)
@@ -99,9 +99,9 @@ def main():
     f.write("\n\n</body></html>")
     f.close()
 
-    result_report = iterateallspecs(runconfig.apispeclist, runconfig.fuzzattacklist)
+    #result_report = iterateallspecs(runconfig.apispeclist, runconfig.fuzzattacklist)
     #print("-----+++",result_report)
-    generate_html_report(result_report, "report_summary_"+str(time.time())+".html")
+    #generate_html_report(result_report, "report_summary_"+str(time.time())+".html")
     
 if __name__ == "__main__":
     # execute only if run as a script
